@@ -88,7 +88,7 @@ class XRedis(Singleton):
                     while not self._make_conn():
                         time.sleep(0.1)
                     
-                    conn = self.conn
+                    conn = self.__get_connection(pipeline, transaction)
            
         return conn
 
